@@ -1,17 +1,18 @@
 package Array::FIFO;
-$Array::FIFO::VERSION = '0.04';
+$Array::FIFO::VERSION = '0.05';
 use Moose;
+use List::Util qw(sum0);
 
 use namespace::autoclean;
 
 
 =head1 NAME
 
-Array::FIFO - Simple FIFO array, with a few convenience methods
+Array::FIFO - A Simple limitable FIFO array, with some convenience methods to crunch the data
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -24,8 +25,17 @@ version 0.04
 
 =head1 DESCRIPTION
 
-Provides access to doppler data via a Doppler::Storage::Engine package
-through an interface provided by a Doppler::Storage::Interface role.
+Array::FIFO is meant to be a simple limitable FIFO array, for storing data in a FIFO
+manner, with an optional limit to how large the array can get.  When the limit is
+reached, the oldest value is discarded when new values are added.
+
+It's intent is for numeric values (i.e. current load of a system), but it should work 
+for other data types.
+
+The C<<sum>> and C<<average>> methods keep the current sum and average of the numbers
+as you would expect.  It does this on the fly, so it's probably not performant enough 
+for very large arrays in most cases.
+
 
 =head1 METHODS
 
@@ -35,7 +45,7 @@ through an interface provided by a Doppler::Storage::Interface role.
 
 =item C<limit> (optional)
 
-Numeric value of how large the array is allowd to get.  When it reaches 
+Numeric value of how large the array is allowed to get.  When it reaches 
 limit, every item added causes the oldest item to be removed.
 
 If no value is passed, there is no max size.
@@ -126,12 +136,7 @@ has queue => (
 
         my $size = $self->size;
 
-        my $sum = 0;
-        foreach my $q (@{ $self->queue }) {
-            if ($q =~ /^-?\d+\.?\d*$/) {
-                $sum += $q;
-            }
-        }
+        my $sum = sum0( grep /^-?\d+\.?\d*$/, @{ $self->queue } );
 
         $self->sum( $sum );
         if ($sum > 0) {
